==> wd-0.2.15.tgz: package/test/midway/midway-base.js <==
/* global sauceJobTitle, mergeDesired, midwayUrl, Express */

module.exports = function(that, partials) {

  that.timeout(env.TIMEOUT);

  var deferred = Q.defer();

  var browser;
  var allPassed = true;
  var express;
  before(function(done) {
    express = new Express( __dirname + '/assets', partials );
    express.start(done);
  });

  before(function() {
    browser = wd.promiseChainRemote(env.REMOTE_CONFIG);
    deferred.resolve(browser);
    var sauceExtra = {
      name: sauceJobTitle(this.runnable().parent.title),
      tags: ['midway']
    };
    var desired = mergeDesired(env.DESIRED, env.SAUCE? sauceExtra : null );
    return browser
      .configureLogging()
      .then(function() {
        return browser
          .init(desired)
          .catch(function() {
            // trying one more time
            return browser.init(desired);
          });
      });
  });

  beforeEach(function() {
    var url = midwayUrl(
      this.currentTest.parent.title,
      this.currentTest.title
    );
    return browser
    .get(url)
    .title().should.eventually.include("WD Tests")
    .catch(function() {
      // trying one more time
      return browser
        .get(url)
        .title().should.eventually.include("WD Tests");
    });
  });

  afterEach(function() {
    allPassed = allPassed && (this.currentTest.state === 'passed');
  });

  after(function() {
    return browser
      .quit().then(function() {
        if(env.SAUCE) { return(browser.sauceJobStatus(allPassed)); }
      });
  });

  after(function(done) {
    express.stop(done);
  });

  return deferred.promise;
};

==> wd-0.3.5.tgz: package/test/midway/midway-base.js <==
/* global sauceJobTitle, mergeDesired, midwayUrl, Express, uuidLib */

module.exports = function(that, partials) {

  that.timeout(env.TIMEOUT);

  var deferred = Q.defer();

  var browser;
  var allPassed = true;
  var express;
  before(function(done) {
    express = new Express( __dirname + '/assets', partials );
    express.start(done);
  });

  before(function() {
    browser = wd.promiseChainRemote(env.REMOTE_CONFIG);
    deferred.resolve(browser);
    var sauceExtra = {
      name: sauceJobTitle(this.runnable().parent.title),
      tags: ['midway']
    };
    var desired = mergeDesired(env.DESIRED, env.SAUCE? sauceExtra : null );
    return browser
      .configureLogging()
      .then(function() {
        return browser
          .init(desired)
          .catch(function() {
            // trying one more time
            return browser.init(desired);
          });
      });
  });

  beforeEach(function() {
    var uuid = uuidLib.v1().substring(0,8);
    var url = midwayUrl({
      testSuite: this.currentTest.parent.title,
      title: this.currentTest.title,
      uuid: uuid  
    });
    return browser
      .get(url)
      .sleep(500)
      .waitForElementById(uuid, 10000, 500)
      .catch(function() {
        return browser
          .sleep(500)
          .get(url)
          .sleep(500)
          .waitForElementById(uuid, 10000, 500);
      }).sleep(100);
  });

  afterEach(function() {
    allPassed = allPassed && (this.currentTest.state === 'passed');
  });

  after(function() {
    return browser
      .quit().then(function() {
        if(env.SAUCE) { return(browser.sauceJobStatus(allPassed)); }
      });
  });

  after(function(done) {
    express.stop(done);
  });

  return deferred.promise;
};
